==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/PERFORMANCEFORMULAVARIABLEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour PERFORMANCEFORMULAVARIABLEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PERFORMANCEFORMULAVARIABLEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RATINGWEIGHT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BESTACCEPTABLERESULT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORSTACCEPTABLERESULT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PERFORMANCEFORMULAVARIABLEID_Type", propOrder = {
    "ratingweight",
    "querycode",
    "bestacceptableresult",
    "worstacceptableresult"
})
public class PERFORMANCEFORMULAVARIABLEID_Type {

    @XmlElement(name = "RATINGWEIGHT")
    protected QUANTITY ratingweight;
    @XmlElement(name = "QUERYCODE")
    protected String querycode;
    @XmlElement(name = "BESTACCEPTABLERESULT")
    protected QUANTITY bestacceptableresult;
    @XmlElement(name = "WORSTACCEPTABLERESULT")
    protected QUANTITY worstacceptableresult;

    /**
     * Obtient la valeur de la propriété ratingweight.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRATINGWEIGHT() {
        return ratingweight;
    }

    /**
     * Définit la valeur de la propriété ratingweight.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRATINGWEIGHT(QUANTITY value) {
        this.ratingweight = value;
    }

    /**
     * Obtient la valeur de la propriété querycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Définit la valeur de la propriété querycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Obtient la valeur de la propriété bestacceptableresult.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBESTACCEPTABLERESULT() {
        return bestacceptableresult;
    }

    /**
     * Définit la valeur de la propriété bestacceptableresult.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBESTACCEPTABLERESULT(QUANTITY value) {
        this.bestacceptableresult = value;
    }

    /**
     * Obtient la valeur de la propriété worstacceptableresult.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWORSTACCEPTABLERESULT() {
        return worstacceptableresult;
    }

    /**
     * Définit la valeur de la propriété worstacceptableresult.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWORSTACCEPTABLERESULT(QUANTITY value) {
        this.worstacceptableresult = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/PERFORMANCEFORMULAVARIABLEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for PERFORMANCEFORMULAVARIABLEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PERFORMANCEFORMULAVARIABLEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RATINGWEIGHT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUERYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BESTACCEPTABLERESULT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORSTACCEPTABLERESULT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PERFORMANCEFORMULAVARIABLEID_Type", propOrder = {
    "ratingweight",
    "querycode",
    "bestacceptableresult",
    "worstacceptableresult"
})
public class PERFORMANCEFORMULAVARIABLEID_Type {

    @XmlElement(name = "RATINGWEIGHT")
    protected QUANTITY ratingweight;
    @XmlElement(name = "QUERYCODE")
    protected String querycode;
    @XmlElement(name = "BESTACCEPTABLERESULT")
    protected QUANTITY bestacceptableresult;
    @XmlElement(name = "WORSTACCEPTABLERESULT")
    protected QUANTITY worstacceptableresult;

    /**
     * Gets the value of the ratingweight property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRATINGWEIGHT() {
        return ratingweight;
    }

    /**
     * Sets the value of the ratingweight property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRATINGWEIGHT(QUANTITY value) {
        this.ratingweight = value;
    }

    /**
     * Gets the value of the querycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQUERYCODE() {
        return querycode;
    }

    /**
     * Sets the value of the querycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQUERYCODE(String value) {
        this.querycode = value;
    }

    /**
     * Gets the value of the bestacceptableresult property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getBESTACCEPTABLERESULT() {
        return bestacceptableresult;
    }

    /**
     * Sets the value of the bestacceptableresult property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setBESTACCEPTABLERESULT(QUANTITY value) {
        this.bestacceptableresult = value;
    }

    /**
     * Gets the value of the worstacceptableresult property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWORSTACCEPTABLERESULT() {
        return worstacceptableresult;
    }

    /**
     * Sets the value of the worstacceptableresult property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWORSTACCEPTABLERESULT(QUANTITY value) {
        this.worstacceptableresult = value;
    }

}
